# Eerie

<p class="lead">
A sensible query string library for python.
</p>


## 🛠 Installing

```
poetry add eerie
```

## 📚 Help

See the [Documentation][docs] or ask questions on the [Discussion][discussions] board.

## ⚖️ Licence

This project is licensed under the [MIT licence][mit_licence].

All documentation and images are licenced under the 
[Creative Commons Attribution-ShareAlike 4.0 International License][cc_by_sa].

## 📝 Meta

This project uses [Semantic Versioning][semvar].

[docs]: https://eerie.artisan.io
[discussions]: https://github.com/orgs/artisanofcode/discussions
[mit_licence]: http://dan.mit-license.org/
[cc_by_sa]: https://creativecommons.org/licenses/by-sa/4.0/
[semvar]: http://semver.org/
